pub struct TaskSpawner { /* private fields */ }Expand description
A generation-bound capability for cancellation-aware child tasks.
Implementations
Sourceimpl TaskSpawner
impl TaskSpawner
Sourcepub fn cancellation_token(&self) -> CancellationToken
pub fn cancellation_token(&self) -> CancellationToken
Returns a non-authoritative cancellation signal for this generation.
Sourcepub fn spawn<F>(&self, future: F) -> Result<(), TaskSpawnError>
pub fn spawn<F>(&self, future: F) -> Result<(), TaskSpawnError>
Registers future before allowing it to poll.
Errors
Returns an error when this spawner no longer belongs to the open generation.
Sourcepub fn spawn_named<F>(
&self,
name: &'static str,
future: F,
) -> Result<TaskRef, TaskSpawnError>
pub fn spawn_named<F>( &self, name: &'static str, future: F, ) -> Result<TaskRef, TaskSpawnError>
Registers a named future before allowing it to poll.
The returned reference observes identity and terminal state without owning cancellation or joining. The task may reach a terminal state before this method returns.
Errors
Returns an error when this spawner no longer belongs to the open generation.
Panics
Panics if the process exhausts the u64 task identifier space.